==> v0.11.0.tar.gz: powertoys/doc/planning/PowerToysBacklog.md <==
# PowerToys Backlog

The list below is the set of utilities we're considering and the rough priority order of the utilities.  If you have feedback on the order of the utilities, please use the issues for each one to provide that feedback.  Note that new features for existing utilities (dock / undock zone layouts for FancyZones) are tracked in teh abcklog for each utility. 

## On deck

* Maximize to new desktop widget - The MTND widget shows a pop-up button when a user hovers over the maximize / restore button on any window.  Clicking it creates a new desktop, sends the app to that desktop and maximizes the app on the new desktop.
* [Process terminate tool](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/Terminate%20Spec.md)
* [Batch file renamer](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/File%20Classification%20Spec.md)
* [Animated gif screen recorder](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/GIF%20Maker%20Spec.md)

## Backlog

HPlease use issues and votes to guide the project to suggest new ideas and help us prioritize the list below.

1. [Keyboard shortcut manager](https://github.com/microsoft/PowerToys/issues/6)
2. [Win+R replacement](https://github.com/microsoft/PowerToys/issues/44)
3. Resrouce use tool (maps between a resource like a file handle to an app and vice-versa)
4. Performance analysis over time to track which processes have been slowing down your machine
5. Better Alt+Tab including browser tab integration and search for running apps
6. [Battery tracker](https://github.com/microsoft/PowerToys/issues/7)
7. [Quick resolution swaps in taskbar](https://github.com/microsoft/PowerToys/issues/27)
8. Mouse events without focus
9. Cmd (or PS or Bash) from here
10. Contents menu file browsing

==> v0.13.0.tar.gz: powertoys/doc/planning/PowerToysBacklog.md <==
# PowerToys Backlog

The list below is the set of utilities we're considering and the rough priority order of the utilities.  If you have feedback on the order of the utilities, please use the issues for each one to provide that feedback.  Note that new features for existing utilities (dock / undock zone layouts for FancyZones) are tracked in the backlog for each utility. 

## On deck

* Maximize to new desktop widget - The MTND widget shows a pop-up button when a user hovers over the maximize / restore button on any window.  Clicking it creates a new desktop, sends the app to that desktop and maximizes the app on the new desktop.
* [Process terminate tool](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/Terminate%20Spec.md)
* [Batch file renamer](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/File%20Classification%20Spec.md)
* [Animated gif screen recorder](https://github.com/indierawk2k2/PowerToys-1/blob/master/specs/GIF%20Maker%20Spec.md)

## Backlog

Please use issues and votes to guide the project to suggest new ideas and help us prioritize the list below.

1. [Keyboard shortcut manager](https://github.com/microsoft/PowerToys/issues/6)
2. [Win+R replacement](https://github.com/microsoft/PowerToys/issues/44)
3. Resource use tool (maps between a resource like a file handle to an app and vice-versa)
4. Performance analysis over time to track which processes have been slowing down your machine
5. Better Alt+Tab including browser tab integration and search for running apps
6. [Battery tracker](https://github.com/microsoft/PowerToys/issues/7)
7. [Quick resolution swaps in taskbar](https://github.com/microsoft/PowerToys/issues/27)
8. Mouse events without focus
9. Cmd (or PS or Bash) from here
10. Contents menu file browsing
